.onLoad <- function(lib, pkg) {
	.Call("AbstractMatrix_init")
}